pub fn cube(groups: impl IntoExprList) -> ExprExpand description
CUBE (a, b) — a grouping element covering every subset of the list.
pub fn cube(groups: impl IntoExprList) -> ExprCUBE (a, b) — a grouping element covering every subset of the list.